@@ -29,6 +29,12 @@ setClass("XVectorList",
 ### GroupedIRanges methods.
 ###
 
+### Combine the new parallel slots with those of the parent class. Make sure
+### to put the new parallel slots *first*.
+setMethod("parallelSlotNames", "GroupedIRanges",
+    function(x) c("group", callNextMethod())
+)
+
 .valid.GroupedIRanges <- function(x)
 {
     if (length(x@group) != length(x))
@@ -47,15 +53,6 @@ setMethod("show", "GroupedIRanges",
     function(object) show(as.data.frame(object))
 )
 
-setMethod("extractROWS", "GroupedIRanges",
-    function(x, i)
-    {
-        i <- extractROWS(setNames(seq_along(x), names(x)), i)
-        x@group <- extractROWS(x@group, i)
-        callNextMethod()
-    }
-)
-
 setMethod("c", "GroupedIRanges",
     function(x, ..., recursive=FALSE)
     {
@@ -81,7 +78,7 @@ setMethod("length", "XVectorList", function(x) length(x@ranges))
 
 setMethod("width", "XVectorList", function(x) width(x@ranges))
 
-setMethod("elementLengths", "XVectorList", function(x) width(x))
+setMethod("elementNROWS", "XVectorList", function(x) width(x))
 
 setMethod("names", "XVectorList", function(x) names(x@ranges))
 
@@ -281,16 +278,9 @@ setMethod("extractROWS", "XVectorList",
 ### subseq()
 ###
 
-narrowXVectorList <- function(x, start=NA, end=NA, width=NA, use.names=TRUE)
-{
-    x@ranges <- narrow(x@ranges, start=start, end=end, width=width,
-                       use.names=use.names)
-    x
-}
-
 setMethod("subseq", "XVectorList",
     function(x, start=NA, end=NA, width=NA)
-        narrowXVectorList(x, start=start, end=end, width=width)
+        narrow(x, start=start, end=end, width=width)
 )
 
 
@@ -361,9 +351,9 @@ unlist_list_of_XVectorList <- function(Class, x,
     ## arg) and use it here.
     ans_ranges <- do.call(c, ranges_slots)
 
-    breakpoints <- cumsum(elementLengths(pool_slots))
+    breakpoints <- cumsum(elementNROWS(pool_slots))
     offsets <- c(0L, breakpoints[-length(breakpoints)])
-    offsets <- rep.int(offsets, elementLengths(ranges_slots))
+    offsets <- rep.int(offsets, elementNROWS(ranges_slots))
     ans_ranges@group <- ans_ranges@group + offsets
 
     ## Combine "mcols" slots.
@@ -444,7 +434,7 @@ setMethod("showAsCell", "XVectorList", function(object) as.character(object))
 ### Not intended for the end user.
 ###
 ### 'f' must be a factor with number of levels equal to 'length(x)' and
-### length equal to 'sum(elementLengths(x))'. 
+### length equal to 'sum(elementNROWS(x))'. 
 unsplit_list_of_XVectorList <- function(classname, x, f)
 {
     ans <- XVectorList(classname, length(f))
