@@ -1,8 +1,6 @@
 #include "../inst/include/XVector_defines.h"
 #include <string.h>
 
-#define DEBUG_XVECTOR 1
-
 #define INTERNAL_ERR_IN "XVector internal error in "
 
 #define INIT_STATIC_SYMBOL(NAME) \
@@ -60,8 +58,6 @@ int _delete_trailing_LF_or_CRLF(
 
 /* Ocopy_byteblocks.c */
 
-SEXP debug_Ocopy_byteblocks();
-
 void _Ocopy_byteblocks_from_i1i2(
 	int i1,
 	int i2,
@@ -252,8 +248,6 @@ void _vector_mcopy(
 
 /* SharedVector_class.c */
 
-SEXP debug_SharedVector_class();
-
 SEXP address_asSTRSXP(SEXP s);
 
 SEXP externalptr_new();
@@ -326,8 +320,6 @@ SEXP _new_SharedVector_Pool1(SEXP shared);
 
 /* SharedRaw_class.c */
 
-SEXP debug_SharedRaw_class();
-
 SEXP SharedRaw_new(
 	SEXP length,
 	SEXP val
@@ -425,8 +417,6 @@ SEXP SharedRaw_read_complexes_from_subscript(
 
 /* SharedInteger_class.c */
 
-SEXP debug_SharedInteger_class();
-
 SEXP SharedInteger_new(
 	SEXP length,
 	SEXP val
@@ -461,8 +451,6 @@ SEXP SharedInteger_write_ints_to_subscript(
 
 /* SharedDouble_class.c */
 
-SEXP debug_SharedDouble_class();
-
 SEXP SharedDouble_new(
 	SEXP length,
 	SEXP val
@@ -497,8 +485,6 @@ SEXP SharedDouble_write_nums_to_subscript(
 
 /* XVector_class.c */
 
-SEXP debug_XVector_class();
-
 SEXP _get_XVector_shared(SEXP x);
 
 int _get_XVector_offset(SEXP x);
@@ -553,8 +539,6 @@ SEXP _alloc_XDouble(
 
 /* XVectorList_class.c */
 
-SEXP debug_XVectorList_class();
-
 SEXP _get_XVectorList_pool(SEXP x);
 
 SEXP _get_XVectorList_ranges(SEXP x);
@@ -671,7 +655,7 @@ SEXP _new_XIntegerList_from_IntAEAE(
 
 /* XRawList_comparison.c */
 
-SEXP XRawList_compare(
+SEXP XRawList_pcompare(
 	SEXP x,
 	SEXP y
 );
