@@ -1,25 +1,11 @@
 /****************************************************************************
  *              Low-level manipulation of XVectorList objects               *
- *                           Author: Herve Pages                            *
+ *                            Author: H. Pag\`es                            *
  ****************************************************************************/
 #include "XVector.h"
 #include "IRanges_interface.h"
 #include "S4Vectors_interface.h"
 
-static int debug = 0;
-
-SEXP debug_XVectorList_class()
-{
-#ifdef DEBUG_XVECTOR
-	debug = !debug;
-	Rprintf("Debug mode turned %s in file %s\n",
-		debug ? "on" : "off", __FILE__);
-#else
-	Rprintf("Debug mode not available in file %s\n", __FILE__);
-#endif
-	return R_NilValue;
-}
-
 
 /****************************************************************************
  * C-level slot getters for XVectorList objects.
